from fastapi import APIRouter, HTTPException
from typing import Dict, Optional, List

from pyexpat import features

from pydantic import BaseModel

import logging

from src.reviewsense_ecom.model.ProductReview import ProductReview
from src.reviewsense_ecom.model.Product import Product
from src.reviewsense_ecom.mongo.MongoClientFactory import MongoClientFactory
from src.reviewsense_ecom.service.ProductDefinitionService import ProductDefinitionService
from src.reviewsense_ecom.service.ReviewAnalysisService import ReviewAnalysisService
from src.reviewsense_ecom.service.StoreReviewAnalysis import add_review_features

router = APIRouter()
# review_service = ReviewService()
# feature_extractor = FeatureExtractor()
review_analysis_service = ReviewAnalysisService()
client = MongoClientFactory.get_client()
product_definition_service = ProductDefinitionService(client)

logger = logging.getLogger(__name__)


class RatingSummary(BaseModel):
    ratings_count: int
    average_rating: float
    rating_distribution: Dict[str, int]
    total_reviews: List[str]


class ReviewResponse(BaseModel):
    review_ratings: Dict[str, Optional[float]]
    ratings_summary: RatingSummary


@router.post("/calculate_ratings/", response_model=Product)
async def calculate_ratings(input_data: ProductReview):
    categories = product_definition_service.get_product_categories(input_data.product_id)

    feature_reviews_analysis = review_analysis_service.generate_feature_reviews_analysis(input_data.review, categories)
    add_review_features(input_data, feature_reviews_analysis)