from pymongo.collection import Collection
from typing import Dict, List, Optional
from pymongo import MongoClient


class ProductDefinitionService:
    """
    Service class to fetch dynamic product categories from the productDefinition collection.
    """

    def __init__(self, client: MongoClient, db_name: str = "productRater", collection_name: str = "productDefinition"):
        """
        Initializes the service with the MongoDB client.

        Args:
            client (MongoClient): MongoDB client instance.
            db_name (str): Name of the database.
            collection_name (str): Name of the collection.
        """
        self.collection: Collection = client[db_name][collection_name]

    def get_product_categories(self, product_id: str) -> Optional[List[str]]:
        """
        Fetches all dynamic product categories under the 'category' field.

        Returns:
            Optional[Dict[str, List[str]]]: A dictionary of categories and their corresponding product lists.
        """
        document = self.collection.find_one({
            'product_id': product_id
        }, {
            'feature_ratings': 1,
            '_id': 0
        })
        return document.get('feature_ratings') if document else None
