import uuid
from typing import List, Dict
from datetime import date, datetime
from src.reviewsense_ecom.model.FeatureSentiment import FeatureSentiment
from src.reviewsense_ecom.model.ProductReview import ProductReview
from src.reviewsense_ecom.mongo.MongoClientFactory import MongoClientFactory


def add_review_features(input_data: ProductReview, reviews_by_feature: List[Dict[str, str]]):
    db_name = "productRater"
    collection_name = "test"

    # Establish MongoDB connection
    client = MongoClientFactory.get_client()
    collection = client[db_name][collection_name]

    # Dictionary to store feature analysis (keeping one FeatureSentiment per feature)
    features_analysis: Dict[str, FeatureSentiment] = {}

    for review in reviews_by_feature:
        feature = review["feature"]
        new_sentence = review["sentence"]
        new_sentiment = review["sentiment"]

        if feature in features_analysis:
            # Option 1: Concatenating sentences if feature already exists
            existing_sentiment = features_analysis[feature]
            existing_sentiment.feature_sentence += f" {new_sentence}"  # Merge sentences
        else:
            # Store new feature sentiment
            features_analysis[feature] = FeatureSentiment(
                feature_sentence=new_sentence,
                feature_sentiment=new_sentiment  # Fixed typo from original code
            )

    # Create a ProductReview object
    new_review = ProductReview(
        product_id=input_data.product_id,
        review_id=f"rev_{uuid.uuid4().hex[:16]}",  # Better uniqueness
        review=input_data.review,
        product_rating=input_data.product_rating,
        review_date=datetime.now(),
        features_analysis=features_analysis
    )

    # Insert into the collection
    collection.insert_one(new_review.dict())  # More explicit than __dict__

    # Close MongoDB connection
    client.close()
